@@ -5,7 +5,9 @@ import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JList;
 import javax.swing.ListCellRenderer;
+import javax.swing.table.TableColumn;
 import javax.swing.plaf.basic.BasicComboBoxRenderer;
+import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.gui.StarTableColumn;
 
 /**
@@ -14,12 +16,11 @@ import uk.ac.starlink.table.gui.StarTableColumn;
  * @author   Mark Taylor (Starlink)
  * @since    20 Feb 2004
  */
-@SuppressWarnings({"unchecked","rawtypes"})
-public class ColumnCellRenderer implements ListCellRenderer {
+public class ColumnCellRenderer implements ListCellRenderer<TableColumn> {
 
-    private final ListCellRenderer baseRenderer_;
+    private final BasicComboBoxRenderer baseRenderer_;
     private Object nullRep_;
-    private JComboBox comboBox_;
+    private JComboBox<TableColumn> comboBox_;
 
     /**
      * Sets up a ColumnCellRenderer for a given combo box.
@@ -28,7 +29,7 @@ public class ColumnCellRenderer implements ListCellRenderer {
      *
      * @param  comboBox  box to watch
      */
-    public ColumnCellRenderer( JComboBox comboBox ) {
+    public ColumnCellRenderer( JComboBox<TableColumn> comboBox ) {
         comboBox_ = comboBox;
 
         /* Should I be getting this from the PLAF somehow? */
@@ -42,24 +43,29 @@ public class ColumnCellRenderer implements ListCellRenderer {
         this( null );
     }
 
-    public Component getListCellRendererComponent( JList list, Object value,
-                                                   int index,
-                                                   boolean isSelected,
-                                                   boolean hasFocus ) {
+    public Component
+            getListCellRendererComponent( JList<? extends TableColumn> list,
+                                          TableColumn col, int index,
+                                          boolean isSelected,
+                                          boolean hasFocus ) {
+        ColumnInfo cinfo = col instanceof StarTableColumn
+                         ? ((StarTableColumn) col).getColumnInfo()
+                         : null;
         Object rep;
-        if ( value == null && nullRep_ != null ) {
+        if ( col == null && nullRep_ != null ) {
             rep = nullRep_;
         }
         else {
-            rep = mapValue( value );
+            rep = cinfo == null
+                ? col
+                : cinfo.getName();
         }
         Component comp = baseRenderer_
                         .getListCellRendererComponent( list, rep, index, 
                                                        isSelected, hasFocus );
-        String descrip = value instanceof StarTableColumn
-                       ? ((StarTableColumn) value).getColumnInfo()
-                                                  .getDescription()
-                       : null;
+        String descrip = cinfo == null
+                       ? null
+                       : cinfo.getDescription();
         if ( comboBox_ != null ) {
             if ( descrip != null && descrip.trim().length() == 0 ) {
                 descrip = null;
@@ -69,19 +75,6 @@ public class ColumnCellRenderer implements ListCellRenderer {
         return comp;
     }
 
-    /**
-     * Provides the representation (to be displayed in the combo box) 
-     * for an object in the box's model.
-     *
-     * @param  value  input value
-     * @return to which <tt>value</tt> is mapped
-     */
-    public Object mapValue( Object value ) {
-        return value instanceof StarTableColumn 
-             ? ((StarTableColumn) value).getColumnInfo().getName()
-             : value;
-    }
-
     /**
      * Sets the representation for the null item.
      *
@@ -90,5 +83,4 @@ public class ColumnCellRenderer implements ListCellRenderer {
     public void setNullRepresentation( Object nullRep ) {
         nullRep_ = nullRep;
     }
-
 }
