@@ -26,17 +26,16 @@ import uk.ac.starlink.util.gui.WeakTableColumnModelListener;
  *
  * @author   Mark Taylor (Starlink)
  */
-@SuppressWarnings({"unchecked","rawtypes"})
-public class ColumnComboBoxModel extends AbstractListModel 
+public class ColumnComboBoxModel extends AbstractListModel<TableColumn>
                                  implements TableColumnModelListener,
-                                            ComboBoxModel {
+                                            ComboBoxModel<TableColumn> {
 
-    private final TableColumnModel colModel;
-    private TableColumn selected;
-    private boolean hasNone;
-    private int dummyCount;
+    private final TableColumnModel colModel_;
+    private Object selected_;
+    private int dummyCount_;
 
-    private static ListCellRenderer colRenderer_ = new ColumnCellRenderer();
+    private static ListCellRenderer<TableColumn> colRenderer_ =
+        new ColumnCellRenderer();
 
     public static final StarTableColumn NO_COLUMN =
         new StarTableColumn( new ColumnInfo( "" ), -1 );
@@ -51,7 +50,7 @@ public class ColumnComboBoxModel extends AbstractListModel
      *                  the list is required
      */
     public ColumnComboBoxModel( TableColumnModel colModel, boolean hasNone ) {
-        this.colModel = colModel;
+        colModel_ = colModel;
         setHasNone( hasNone );
         colModel.addColumnModelListener( 
             new WeakTableColumnModelListener( this ) );
@@ -64,31 +63,25 @@ public class ColumnComboBoxModel extends AbstractListModel
      *                  the list is required
      */
     public void setHasNone( boolean hasNone ) {
-        this.hasNone = hasNone;
-        this.dummyCount = hasNone ? 1 : 0;
+        dummyCount_ = hasNone ? 1 : 0;
     }
 
     public TableColumnModel getColumnModel() {
-        return colModel;
+        return colModel_;
     }
 
-    public Object getElementAt( int index ) {
-        index -= dummyCount;
-        return index >= 0 ? colModel.getColumn( index ) : NO_COLUMN;
+    public TableColumn getElementAt( int index ) {
+        index -= dummyCount_;
+        return index >= 0 ? colModel_.getColumn( index )
+                          : NO_COLUMN;
     }
 
     public int getSize() {
-        return colModel.getColumnCount() + dummyCount;
+        return colModel_.getColumnCount() + dummyCount_;
     }
 
-    /**
-     * The returned object is guaranteed to be a 
-     * {@link javax.swing.table.TableColumn} or null.
-     *
-     * @return  the selected <tt>TableColumn</tt>
-     */
     public Object getSelectedItem() {
-        return selected;
+        return selected_;
     }
 
     /**
@@ -96,12 +89,10 @@ public class ColumnComboBoxModel extends AbstractListModel
      * {@link javax.swing.table.TableColumn} object.
      *
      * @param  item  a table column to select
-     * @throws ClassCastException  if <tt>item</tt> is not null or a 
-     *         <tt>TableColumn</tt>
      */
     public void setSelectedItem( Object item ) {
-        if ( selected != item ) {
-            selected = (TableColumn) item;
+        if ( selected_ != item ) {
+            selected_ = item;
 
             /* This bit of magic is copied from the J2SE1.4 
              * DefaultComboBoxModel implementation - seems to be necessary
@@ -119,35 +110,33 @@ public class ColumnComboBoxModel extends AbstractListModel
      * @return  new combo box displaying this model
      * @see     ColumnCellRenderer
      */
-    public JComboBox makeComboBox() {
-        JComboBox box = new JComboBox( this );
+    public JComboBox<TableColumn> makeComboBox() {
+        JComboBox<TableColumn> box = new JComboBox<TableColumn>( this );
         box.setRenderer( colRenderer_ );
         return box;
     }
 
-
     /*
      * Implementation of the TableColumnModelListener interface.
      */
 
     public void columnAdded( TableColumnModelEvent evt ) {
-        int index = dummyCount + evt.getToIndex();
+        int index = dummyCount_ + evt.getToIndex();
         fireIntervalAdded( this, index, index );
     }
 
     public void columnRemoved( TableColumnModelEvent evt ) {
-        int index = dummyCount + evt.getFromIndex();
+        int index = dummyCount_ + evt.getFromIndex();
         fireIntervalRemoved( this, index, index );
     }
 
     public void columnMoved( TableColumnModelEvent evt ) {
-        int index0 = dummyCount + evt.getFromIndex();
-        int index1 = dummyCount + evt.getToIndex();
+        int index0 = dummyCount_ + evt.getFromIndex();
+        int index1 = dummyCount_ + evt.getToIndex();
         fireContentsChanged( this, index0, index1 );
     }
 
     public void columnMarginChanged( ChangeEvent evt ) {}
 
     public void columnSelectionChanged( ListSelectionEvent evt ) {}
-    
 }
