@@ -5,6 +5,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
+import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
@@ -89,12 +90,6 @@ public class TopcatCodec2 implements TopcatCodec {
     private static final ColumnSetSpec COL_SETSPEC = new ColumnSetSpec();
     private static final BitSetSpec BIT_SETSPEC = new BitSetSpec();
 
-    private static final RowSubset DELETED_SUBSET = new RowSubset( "DELETED" ) {
-        public boolean isIncluded( long lrow ) {
-            return false;
-        }
-    };
-
     private final static int MAX_NBIT = Integer.SIZE;
 
     private static final Logger logger_ =
@@ -188,7 +183,7 @@ public class TopcatCodec2 implements TopcatCodec {
                 hadAll = true;
                 sspec = ALL_SETSPEC.createStringSpec();
             }
-            else if ( rset == DELETED_SUBSET ) {
+            else if ( rset instanceof DeletedSubset ) {
                 sspec = DEL_SETSPEC.createStringSpec();
             }
             else if ( rset instanceof SyntheticRowSubset ) {
@@ -427,7 +422,8 @@ public class TopcatCodec2 implements TopcatCodec {
         String[] rsetSpecs = (String[]) pset.getCodecValue( SUBSET_SPECS_INFO );
         int nset = rsetSpecs.length;
         RowSubset[] rsets = new RowSubset[ nset ];
-        Map<RowSubset,String> rsetExprMap = new HashMap<RowSubset,String>();
+        Map<RowSubset,String> rsetExprMap = new HashMap<>();
+        Map<RowSubset,Integer> rsetInvMap = new HashMap<>();
         for ( int is = 0; is < nset; is++ ) {
             String rsetName = rsetNames[ is ];
             String rsetSpec = rsetSpecs[ is ];
@@ -436,7 +432,15 @@ public class TopcatCodec2 implements TopcatCodec {
                 rset = RowSubset.ALL;
             }
             else if ( DEL_SETSPEC.isSpec( rsetSpec ) ) {
-                rset = DELETED_SUBSET;
+                rset = new DeletedSubset();
+
+                /* The name picked up from the session file is "DELETED"
+                 * for all deleted subsets, which was a bad decision when
+                 * writing the serialization format.  Having multiple subsets
+                 * with the same name will confuse the subset indexing,
+                 * so do something to make sure the names are unique in case
+                 * there is more than one deleted subset. */
+                rsetName = "***DELETED***" + is;
             }
             else if ( EXPR_SETSPEC.isSpec( rsetSpec ) ) {
                 String expr = EXPR_SETSPEC.getExpression( rsetSpec );
@@ -450,6 +454,7 @@ public class TopcatCodec2 implements TopcatCodec {
             else if ( INV_SETSPEC.isSpec( rsetSpec ) ) {
                 int subsetId = INV_SETSPEC.getSubsetId( rsetSpec );
                 rset = new InverseRowSubset( rsets[ subsetId ] );
+                rsetInvMap.put( rset, Integer.valueOf( subsetId ) );
             }
             else if ( COL_SETSPEC.isSpec( rsetSpec ) ) {
                 int ic = COL_SETSPEC.getColumnIndex( rsetSpec );
@@ -515,26 +520,11 @@ public class TopcatCodec2 implements TopcatCodec {
                            ? jndexCurrentSubset.intValue()
                            : -1;
 
-        /* Add row subsets to topcatmodel. */
-        int iCurrentSubset = -1;
-        for ( int js = 0; js < rsets.length; js++ ) {
-            RowSubset rset = rsets[ js ];
-
-            /* ALL is added at construction of the TopcatModel,
-             * so don't add it again. */
+        /* Add row subsets to the TopcatModel, except for ALL, which is
+         * added as part of TopcatModel construction. */
+        for ( RowSubset rset : rsets ) {
             if ( rset != RowSubset.ALL ) {
                 tcModel.addSubset( rset );
-
-                /* If the set is marked deleted, delete it here.
-                 * It's not good enough just to avoid adding it in the
-                 * first place, since that would get the unique identifiers
-                 * (_ID values) wrong. */
-                if ( rset == DELETED_SUBSET ) {
-                    tcModel.getSubsets().remove( rset );
-                }
-                else if ( jCurrentSubset == js ) {
-                    iCurrentSubset = tcModel.getSubsets().size() - 1;
-                }
             }
         }
 
@@ -570,13 +560,16 @@ public class TopcatCodec2 implements TopcatCodec {
             }
         }
 
-        /* Next do the algebraic subsets. */
+        /* Next do the algebraic and inverse subsets. */
         OptionsListModel<RowSubset> subsets = tcModel.getSubsets();
         for ( int is = 0; is < subsets.size(); is++ ) {
             RowSubset rset0 = subsets.get( is );
-            String expr = rsetExprMap.get( rset0 );
-            if ( expr != null ) {
-                String name = rset0.getName();
+            String name = rset0.getName();
+
+            /* If it was an algebraic subset, recompile it using the symbols
+             * that are now in place. */
+            if ( rsetExprMap.containsKey( rset0 ) ) {
+                String expr = rsetExprMap.get( rset0 );
                 try {
                     RowSubset rset1 =
                         new SyntheticRowSubset( name, tcModel, expr );
@@ -588,11 +581,33 @@ public class TopcatCodec2 implements TopcatCodec {
                                + "(" + expr + ")", e );
                 }
             }
+
+            /* If it was an inverse subset, reconstruct it pointing at the
+             * actual rather than placeholder complement it references. */
+            else if ( rsetInvMap.containsKey( rset0 ) ) {
+                int subsetId = rsetInvMap.get( rset0 ).intValue();
+                RowSubset rset1 =
+                    new InverseRowSubset( subsets.get( subsetId ) );
+                assert rset0.getName().equals( rset1.getName() );
+                subsets.set( is, rset1 );
+            }
         }
 
         /* I don't think this is required, but it can't hurt. */
         tcModel.recompileSubsets();
 
+        /* Remove any subsets marked as deleted.  We have to add them first
+         * and then delete them here, so the unique identifiers (_ID values)
+         * and other setup uses the correct indices. */
+        RowSubset currentSubset = tcModel.getSubsets().get( jCurrentSubset );
+        for ( Iterator<RowSubset> rsIt = tcModel.getSubsets().iterator();
+              rsIt.hasNext(); ) {
+            if ( rsIt.next() instanceof DeletedSubset ) {
+                rsIt.remove();
+            }
+        }
+        int iCurrentSubset = tcModel.getSubsets().indexOf( currentSubset );
+
         /* Restore activation actions. */
         String activTxt = (String) pset.getCodecValue( ACTIVATION_INFO );
         if ( activTxt != null ) {
@@ -743,7 +758,7 @@ public class TopcatCodec2 implements TopcatCodec {
         for ( int id = 0; id < maxId + 1; id++ ) {
             int ix = subsetModel.idToIndex( id );
             subsetArray[ id ] = ix >= 0 ? subsetModel.get( ix )
-                                        : DELETED_SUBSET;
+                                        : new DeletedSubset();
         }
         return subsetArray;
     }
@@ -854,6 +869,18 @@ public class TopcatCodec2 implements TopcatCodec {
         }
     }
 
+    /**
+     * RowSubset implementation to represent a subset that has been deleted.
+     */
+    private static class DeletedSubset extends RowSubset {
+        DeletedSubset() {
+            super( "DELETED" );
+        }
+        public boolean isIncluded( long lrow ) {
+            return false;
+        }
+    };
+
     /**
      * Utility class to package a list of table parameters and
      * interrogate them, especially for information that has been
