@@ -36,6 +36,8 @@ import uk.ac.starlink.table.DefaultValueInfo;
 import uk.ac.starlink.table.JoinFixAction;
 import uk.ac.starlink.table.JoinStarTable;
 import uk.ac.starlink.table.RowSequence;
+import uk.ac.starlink.table.RowSplittable;
+import uk.ac.starlink.table.SequentialRowSplittable;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.StoragePolicy;
@@ -985,6 +987,9 @@ public class DalMultiPanel extends JPanel {
                             }
                         };
                     }
+                    public RowSplittable getRowSplittable() throws IOException {
+                        return new SequentialRowSplittable( this );
+                    }
                 };
 
                 /* And pass the table to the appropriate result handler.
