@@ -31,8 +31,6 @@ import uk.ac.starlink.topcat.plot2.PlanePlotWindow;
 import uk.ac.starlink.topcat.plot2.SkyPlotWindow;
 import uk.ac.starlink.topcat.plot2.SpherePlotWindow;
 import uk.ac.starlink.topcat.plot2.StackPlotWindow;
-import uk.ac.starlink.ttools.plot.MarkShape;
-import uk.ac.starlink.ttools.plot.Styles;
 import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.Plotter;
@@ -46,6 +44,7 @@ import uk.ac.starlink.ttools.plot2.geom.PlaneDataGeom;
 import uk.ac.starlink.ttools.plot2.geom.SkyDataGeom;
 import uk.ac.starlink.ttools.plot2.geom.SphereDataGeom;
 import uk.ac.starlink.ttools.plot2.layer.MarkForm;
+import uk.ac.starlink.ttools.plot2.layer.MarkerShape;
 import uk.ac.starlink.ttools.plot2.layer.PairLinkForm;
 import uk.ac.starlink.ttools.plot2.layer.ShapeMode;
 import uk.ac.starlink.ttools.plot2.layer.ShapePlotter;
@@ -60,11 +59,11 @@ import uk.ac.starlink.util.gui.ErrorDialog;
  */
 public abstract class MatchPlotter {
 
-    private static final MarkShape[] SINGLE_SHAPES = new MarkShape[] {
-        MarkShape.CROXX,
-        MarkShape.CROSS,
-        MarkShape.OPEN_TRIANGLE_UP,
-        MarkShape.OPEN_TRIANGLE_DOWN,
+    private static final MarkerShape[] SINGLE_SHAPES = new MarkerShape[] {
+        MarkerShape.CROXX,
+        MarkerShape.CROSS,
+        MarkerShape.OPEN_TRIANGLE_UP,
+        MarkerShape.OPEN_TRIANGLE_DOWN,
     };
     private static final Color[] SINGLE_COLORS =
         ColorConfigKey.getPlottingColors();
@@ -283,7 +282,7 @@ public abstract class MatchPlotter {
             ConfigMap config = new ConfigMap();
             config.put( StyleKeys.COLOR,
                         SINGLE_COLORS[ iin % SINGLE_COLORS.length ] );
-            config.put( StyleKeys.MARK_SHAPE,
+            config.put( StyleKeys.MARKER_SHAPE,
                         SINGLE_SHAPES[ iin % SINGLE_SHAPES.length ] );
             config.put( StyleKeys.SIZE, 2 );
             return config;
@@ -297,7 +296,7 @@ public abstract class MatchPlotter {
         public ConfigMap createMarkConfigN() {
             ConfigMap config = new ConfigMap();
             config.put( StyleKeys.COLOR, Color.gray );
-            config.put( StyleKeys.MARK_SHAPE, MarkShape.OPEN_CIRCLE );
+            config.put( StyleKeys.MARKER_SHAPE, MarkerShape.OPEN_CIRCLE );
             config.put( StyleKeys.SIZE, 3 );
             return config;
         }
@@ -327,8 +326,7 @@ public abstract class MatchPlotter {
              * by looking at the values the user entered into the
              * TupleSelectors to specify the match. */
             Plotter<ShapeStyle> plotter1 =
-                new ShapePlotter.ShapeModePlotter( "input", MarkForm.SINGLE,
-                                                   markMode1_ );
+                new ShapePlotter( "input", MarkForm.SINGLE, markMode1_ );
             for ( int iin = 0; iin < nin; iin++ ) {
                 TupleSelector tsel = tselectors[ iin ];
                 String[] texprs = tsel.getTupleExpressions();
@@ -420,9 +418,8 @@ public abstract class MatchPlotter {
             /* Use the calculated information to set up a new layer creation
              * command. */
             Plotter<ShapeStyle> markPlotterN =
-                new ShapePlotter
-                   .ShapeModePlotter( "result", MarkForm.createMarkForm( nin ),
-                                      markModeN_ );
+                new ShapePlotter( "result", MarkForm.createMarkForm( nin ),
+                                  markModeN_ );
             LayerCommand<?> markCmd =
                 new LayerCommand<ShapeStyle>( markPlotterN, result,
                                               coordValuesN, createMarkConfigN(),
@@ -430,8 +427,7 @@ public abstract class MatchPlotter {
             controlManager.addLayer( markCmd );
             if ( nin == 2 ) {
                 Plotter<ShapeStyle> linkPlotter =
-                    new ShapePlotter
-                   .ShapeModePlotter( "result", PairLinkForm.getInstance(),
+                    new ShapePlotter( "result", PairLinkForm.getInstance(),
                                       markModeN_ );
                 LayerCommand<?> linkCmd =
                     new LayerCommand<ShapeStyle>( linkPlotter, result,
