@@ -34,6 +34,7 @@ import uk.ac.starlink.ttools.plot2.ReportMap;
 import uk.ac.starlink.ttools.plot2.config.ConfigException;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
+import uk.ac.starlink.ttools.plot2.config.Specifier;
 import uk.ac.starlink.topcat.ActionForwarder;
 import uk.ac.starlink.topcat.AuxWindow;
 import uk.ac.starlink.topcat.RowSubset;
@@ -51,7 +52,6 @@ import uk.ac.starlink.util.gui.ShrinkWrapper;
  * @author   Mark Taylor
  * @since    15 Mar 2013
  */
-@SuppressWarnings({"unchecked","rawtypes"})
 public class FormStylePanel extends JPanel {
 
     private final Configger plotConfigger_;
@@ -59,12 +59,13 @@ public class FormStylePanel extends JPanel {
     private final SubsetConfigManager subManager_;
     private final SubsetStack subStack_;
     private final TopcatModel tcModel_;
+    private final SpecialDefault<?>[] specialDflts_;
     private final OptionalConfigSpecifier globalSpecifier_;
     private final ActionForwarder forwarder_;
     private final Map<RowSubset,ConfigMap> subsetConfigs_;
     private final JLabel iconLabel_;
     private final JComponent subsetSpecifierHolder_;
-    private final JComboBox subsetSelector_;
+    private final JComboBox<RowSubset> subsetSelector_;
     private final ConfigSpecifier subsetSpecifier_;
 
     /**
@@ -88,6 +89,7 @@ public class FormStylePanel extends JPanel {
         subManager_ = subManager;
         subStack_ = subStack;
         tcModel_ = tcModel;
+        specialDflts_ = new SpecialDefault<?>[] { SpecialDefault.SIZE };
         forwarder_ = new ActionForwarder();
 
         /* Set up specifier for global keys. */
@@ -123,7 +125,8 @@ public class FormStylePanel extends JPanel {
 
         /* Set up a selector which will allow access to per-subset configs. */
         subsetSelector_ =
-            new JComboBox( new Plus1ListModel( tcModel.getSubsets(), null ) );
+            new JComboBox<RowSubset>(
+                new Plus1ListModel<RowSubset>( tcModel.getSubsets(), null ) );
         subsetSelector_.addActionListener( new ActionListener() {
             public void actionPerformed( ActionEvent evt ) {
                 RowSubset subset = getSelectedSubset();
@@ -151,6 +154,9 @@ public class FormStylePanel extends JPanel {
         subsetConfigs_ = new HashMap<RowSubset,ConfigMap>();
         subsetSelector_.setSelectedItem( null );
 
+        /* Apply table-sensitive default values. */
+        applySpecialDefaults();
+
         /* Set up a checkbox to display/control visibility of the selected
          * subset.  This can be controlled elsewhere (the SubsetStack in
          * the Subsets tab), but it's useful to have a reminder here.
@@ -247,6 +253,10 @@ public class FormStylePanel extends JPanel {
                 subsetConfigs_.put( rset, config );
             }
         }
+
+        /* Overwrite options that have table-specific defaults
+         * as appropriate. */
+        applySpecialDefaults();
     }
 
     /**
@@ -353,8 +363,7 @@ public class FormStylePanel extends JPanel {
      * @return  selected subset, may be null
      */
     private RowSubset getSelectedSubset() {
-        Object item = subsetSelector_.getSelectedItem();
-        return item instanceof RowSubset ? (RowSubset) item : null;
+        return subsetSelector_.getItemAt( subsetSelector_.getSelectedIndex() );
     }
 
     /**
@@ -430,6 +439,41 @@ public class FormStylePanel extends JPanel {
         return visBox;
     }
 
+    /**
+     * Customises this panel's specifiers according to table-sensitive
+     * defaulting policies.
+     */
+    private void applySpecialDefaults() {
+        if ( tcModel_ != null ) {
+            for ( SpecialDefault<?> special : specialDflts_ ) {
+                customiseDefault( globalSpecifier_, special, tcModel_ );
+                customiseDefault( subsetSpecifier_, special, tcModel_ );
+            }
+        }
+    }
+
+    /**
+     * Customises a ConfigSpecifier according to a supplied table-sensitive
+     * default policy.
+     *
+     * @param  configSpecifier   specifier that may contain a relevant
+     *                           config item
+     * @param  special  object that applies table-sensitive default values
+     * @param  tcModel   table
+     */
+    private static <T> void customiseDefault( ConfigSpecifier configSpecifier,
+                                              SpecialDefault<T> special,
+                                              TopcatModel tcModel ) {
+        Specifier<T> itemSpecifier =
+            configSpecifier.getSpecifier( special.getKey() );
+        if ( itemSpecifier != null ) {
+            T dflt = special.getDefaultValue( tcModel );
+            if ( dflt != null ) {
+                itemSpecifier.setSpecifiedValue( dflt );
+            }
+        }
+    }
+
     /**
      * Listens to changes in the global style config panel.
      * Any changes made explicitly to it are written in to the per-subset
@@ -549,10 +593,10 @@ public class FormStylePanel extends JPanel {
      * existing ones.  It is backed by a live base model, and any changes
      * to that will be reflected here.
      */
-    private static class Plus1ListModel extends AbstractListModel
-                                        implements ComboBoxModel {
-        private final ListModel baseModel_;
-        private final Object item0_;
+    private static class Plus1ListModel<T> extends AbstractListModel<T>
+                                           implements ComboBoxModel<T> {
+        private final ListModel<T> baseModel_;
+        private final T item0_;
         private Object selectedItem_;
 
         /**
@@ -561,7 +605,7 @@ public class FormStylePanel extends JPanel {
          * @param  baseModel   base list model
          * @param  item0  entry to insert first in the list
          */
-        Plus1ListModel( ListModel baseModel, Object item0 ) {
+        Plus1ListModel( ListModel<T> baseModel, T item0 ) {
             baseModel_ = baseModel;
             item0_ = item0;
             baseModel.addListDataListener( new ListDataListener() {
@@ -584,7 +628,7 @@ public class FormStylePanel extends JPanel {
             return baseModel_.getSize() + 1;
         }
 
-        public Object getElementAt( int ix ) {
+        public T getElementAt( int ix ) {
             return ix == 0 ? item0_ : baseModel_.getElementAt( ix - 1 );
         }
 
